# Filename:     tb_counter_integer.do
# Filetype:     Modelsim Script File
# Date:         9 mar 2014
# Update:       -
# Description:  Script File For Automatic Simulation
# Author:       J. op den Brouw
# State:        Demo
# Error:        -
# Version:      1.2
# Copyright:    (c)2014, De Haagse Hogeschool

# Transcript window
transcript on

# Recreate working directories. Quartus wants an RTL
# work directory for RTL simulation.
if {[file exists rtl_work]} {
	vdel -lib rtl_work -all
}
# Create RTL work library and use it as work
vlib rtl_work
vmap work rtl_work

# Find out if we're started through Quartus or by hand
#(or by using an exec in the Tcl window in Quartus).
# Quartus has the annoying property that it will start
# Modelsim from a directory called "simulation/modelsim".
# The design and the testbench are located in the project
# root, so we've to compensate for that.
if [ string match "*simulation/modelsim" [pwd] ] { 
	set prefix "../../"
	puts "Running Modelsim from Quartus..."
} else {
	set prefix ""
	puts "Running Modelsim..."
}

# Compile counter and its testbench, please note that
# the design and its testbench are located in the project
# root, but the simulator starts in directory
# <project_root>/simulation/modelsim, so we have to compensate
# for that.
vcom -93 -work work ${prefix}counter_integer.vhd
vcom -93 -work work ${prefix}tb_counter_integer.vhd

# Start simulation
vsim -t 1ns -L rtl_work -L work -voptargs="+acc"  tb_counter_integer

# Log all signals in the design, good if the number
# of signals is small.
add log -r *

# Add all toplevel signals
# Add a number of signals of the simulated design
add list clk
add list areset
add list load
add list data
add list q
add list tc

# Add all toplevel signals
# Add a number of signals of the simulated design
add wave -divider "Inputs"
add wave clk
add wave areset
add wave load
add wave data
add wave -divider "Internals"
add wave dut/count_val
add wave -divider "Outputs"
add wave q
add wave tc
#add wave -format analog-step -radix unsigned -min 0 -max 15 -height 50 q

# Open List and Waveform window
view list
view wave

# Run simulation for 5000 ns
run 5000 ns

# Scale wave window to fulle zoom
wave zoom full
