-- Filename:     tb_counter_integer.vhd
-- Filetype:     VHDL Testbench
-- Date:         9 mar 2014
-- Update:       -
-- Description:  A testbench for a counter using integers
-- Author:       J. op den Brouw
-- State:        demo
-- Error:        -
-- Version:      1.1
-- Copyright:    (c)2014, De Haagse Hogeschool

-- The design file contains the description of testbench
-- for a counter based on integers.

-- Use library std_logic_1164
-- Use library numeric_std for conversion
library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

-- Empty testbench entity
entity tb_counter_integer is
end entity tb_counter_integer;

-- The testbench...
architecture testbench of tb_counter_integer is
-- The counter to be tested.
component counter_integer is
	generic (n   : positive := 8);
	port (clk    : in std_logic;
			areset : in std_logic;
			load   : in std_logic;
			data   : in unsigned(n-1 downto 0);
			q      : out unsigned(n-1 downto 0);
			tc     : out std_logic
	);
end component counter_integer;
-- Glue signals & to monitor
signal clk    : std_logic;
signal areset : std_logic;
signal load   : std_logic;
signal data   : unsigned(7 downto 0);
signal q      : unsigned(7 downto 0);
signal tc   : std_logic;

begin

	-- Instantiate the counter
	dut : counter_integer
	generic map (n => 8)
	port map(clk => clk, areset => areset, load => load, data => data, q => q, tc => tc);
	
	-- Generating the clock signal at 50 MHz
	genclk : process
	begin
		loop
			clk <= '0';
			wait for 10 ns;
			clk <= '1';
			wait for 10 ns;
		end loop;
	end process genclk;
	
	-- Generating the data
	genstim : process
	begin
		-- Reset the system
		areset <= '1';
		load <= '0';
		wait for 5 ns;
		areset <= '0';
		wait until clk = '1';
		wait for 2 ns;
		
		-- Set the reference to 80H
		-- and run...
		data <= "10000000";
		load <= '1';
		wait until clk = '1';
		wait for 2 ns;
		load <= '0';

		wait;
	end process;
	
end architecture testbench;